<?php
/**
 * Plugin Name:       Tipping at Cart and Checkout
 * Plugin URI:        https://woocommerce.com/products/addify-tipping-at-cart-checkout/
 * Description:       Tips & Donation for WooCommerce empowers online store owners to seamlessly integrate a tipping and donation system into their WooCommerce platform.
 * Version:           1.1.0
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:       addify-tipping-at-cart-checkout
* WC requires at least: 4.0
* WC tested up to: 9.*.*
* Requires at least: 6.5
* Tested up to: 6.*.*
* Requires PHP: 7.4
 *
 * @package addify-tipping-at-cart-checkout
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
/**
 * This check is used to verify is wocommerce plugin is activatd or not
 *
 * @since Woocommerce plugin check
 */

	/**
	 * Class af_Wss_Simple_Stats_Main
	 */
class AF_Woo_Tipping_Or_Donation_Main {
	/**
	 * Class constructor.
	 */
	public function __construct() {

		$this->af_tbw_constant_define();
		add_action( 'plugins_loaded', array( $this, 'af_tbw_init' ) );
		add_action( 'init', array( $this, 'af_tbw_plugin_init' ) );
		add_action( 'woocommerce_blocks_loaded', array( $this, 'af_tbw_block_init' ) );
		add_action( 'before_woocommerce_init', array( $this, 'af_tbw_h_o_p_s_compatibility' ) );
	}

	/**
	 * Af_tbw_plugin_init
	 */
	public function af_tbw_plugin_init() {
		if ( defined( 'WC_PLUGIN_FILE' ) ) {
			$this->af_tbw_create_donation_total_post_type();
			include_once AF_T_B_W_PLUGIN_DIR . 'includes/class-af-tbw-ajax-controller.php';
			if ( is_admin() ) {
				include_once AF_T_B_W_PLUGIN_DIR . 'includes/admin/class-af-woo-tipping-or-donation-admin.php';
			} else {
				include_once AF_T_B_W_PLUGIN_DIR . 'includes/front/class-af-woo-tipping-or-donation-front.php';
			}
			add_action( 'after_setup_theme', array( $this, 'af_tbw_load_plugin_textdomain' ) );
			if (is_cart() & is_checkout()) {
				if ( ! is_admin() && ( WC()->cart->is_empty() ) ) {

					$this->af_tbw_session_ckeck_unset();
				}
			}
		}
	}

	/**
	 * Af_tbw_init
	 */
	public function af_tbw_init() {

		if ( ! is_multisite() && ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) ) {

			add_action( 'admin_notices', array( $this, 'deactive_tipping_or_donation_plugin' ) );

		}
	}

	/**
	 * Af_tbw_session_ckeck_unset
	 */
	public function af_tbw_session_ckeck_unset() {
		WC()->session->set( 'af_tbw_tipping_detail', 0 );
		WC()->session->set( 'af_tbw_tipping_donation_percentage', 0 );
		WC()->session->set( 'af_tbw_tipping_donation_fixed', 0 );
		WC()->session->set( 'af_tbw_tipping_donation_percentage_calculated', 0 );
	}

	/**
	 * Deactive_tipping_or_donation_plugin
	 */
	public function deactive_tipping_or_donation_plugin() {
		// Deactivate the plugin.
		deactivate_plugins( __FILE__ );

		?>
		<div id="message" class="error">
			<p>
				<strong> 
				<?php esc_html_e( 'Tipping or donation for WooCommerce plugin is inactive. WooCommerce plugin must be active in order to activate it.', 'addify-tipping-at-cart-checkout' ); ?>
				</strong>
			</p>
		</div>
		<?php
	}

	/**
	 * Af_tbw_constant_define.
	 */
	public function af_tbw_constant_define() {

		if ( ! defined( 'AF_T_B_W_PLUGIN_URL' ) ) {
			define( 'AF_T_B_W_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
		}

		if ( ! defined( 'AF_T_B_W_PLUGIN_DIR' ) ) {
			define( 'AF_T_B_W_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
	}
	/**
	 * Initialize the plugin.
	 */
	public function af_tbw_load_plugin_textdomain() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
			load_plugin_textdomain( 'addify-tipping-at-cart-checkout', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}
	}
	/**
	 * Af_tbw_h_o_p_s_Compatibility.
	 */
	public function af_tbw_h_o_p_s_compatibility() {

		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}
	/**
	 * Af_tbw_create_donation_total_post_type.
	 */
	public function af_tbw_create_donation_total_post_type() {
		$labels = array(
			'name'               => __( 'Tipping/Donation', 'addify-tipping-at-cart-checkout' ),
			'singular_name'      => __( 'Tipping/Donation', 'addify-tipping-at-cart-checkout' ),
			'menu_name'          => __( 'Tipping/Donation', 'addify-tipping-at-cart-checkout' ),
			'name_admin_bar'     => __( 'Tipping/Donation', 'addify-tipping-at-cart-checkout' ),
			'all_items'          => __( 'All Tipping/Donation Totals', 'addify-tipping-at-cart-checkout' ),
			'parent_item_colon'  => __( 'Parent Tipping/Donation:', 'addify-tipping-at-cart-checkout' ),
			'not_found'          => __( 'No Tipping/Donation found.', 'addify-tipping-at-cart-checkout' ),
			'not_found_in_trash' => __( 'No donation totals found in Trash.', 'addify-tipping-at-cart-checkout' ),
		);

		$args = array(
			'labels'               => $labels,
			'public'               => true,
			'publicly_queryable'   => true,
			'show_ui'              => true,
			'show_in_menu'         => false,
			'query_var'            => true,
			'rewrite'              => array( 'slug' => 'donation-total' ),
			'supports'             => false,
			'show_in_new'          => false,
			'bulk_actions'         => false,
			'capabilities'         => array(
				'create_posts'  => 'do_not_allow',
				'delete_posts'  => 'do_not_allow',
				'restore_posts' => 'do_not_allow',
			),
			// 'map_meta_cap'       => true, //use this option if you need check boxes.
			'register_meta_box_cb' => null, // Remove all meta boxes.
		);

		register_post_type( 'donation_total', $args );
	}
	public function af_tbw_block_init() {
			
		require_once AF_T_B_W_PLUGIN_DIR . '/block-compatibility/af-tpd-cart-block.php';
		require_once AF_T_B_W_PLUGIN_DIR . '/block-compatibility/af-tpd-checkout-block.php';
		if ( class_exists( 'Af_Dontation_Cart_Block' ) ) {
			add_action(
			'woocommerce_blocks_cart_block_registration',
				function () {
					new Af_Dontation_Cart_Block();
				}
			);
		}
		if ( class_exists( 'Af_Dontation_Checkout_Block' ) ) {
			add_action(
				'woocommerce_blocks_checkout_block_registration',
				function () {
					new Af_Dontation_Checkout_Block();
				}
			);
		}
	}
}

new AF_Woo_Tipping_Or_Donation_Main();
